@@ -236,37 +236,11 @@ def flash(release, pull):
     run_flasher(release, 'flash')
 
 
-@cli.command()
-@click.option('--release', default=None, help='Brewblox release track')
-@click.option('--pull/--no-pull', default=True)
-@click.option('--force', is_flag=True, help='Force flashing the bootloader')
-def bootloader(release, pull, force):
-    """Flash bootloader on Spark.
-
-    The bootloader is updated only very rarely.
-    You do not have to run this command for every update.
-
-    This requires the Spark to be connected over USB.
-
-    \b
-    Steps:
-        - Stop running services.
-        - Pull flasher image.
-        - Run bootloader command.
-    """
-    utils.confirm_mode()
-    utils.confirm_usb()
-    prepare_flasher(release, pull)
-
-    utils.info('Flashing bootloader...')
-    run_flasher(release, 'flash-bootloader')
-
-
 @cli.command()
 @click.option('--release', default=None, help='Brewblox release track')
 @click.option('--pull/--no-pull', default=True)
 def wifi(release, pull):
-    """Configure Spark Wifi settings.
+    """DISABLED: Configure Spark Wifi settings.
 
     This requires the Spark to be connected over USB.
 
@@ -276,12 +250,15 @@ def wifi(release, pull):
         - Pull flasher image.
         - Run wifi command.
     """
-    utils.confirm_mode()
-    utils.confirm_usb()
-    prepare_flasher(release, pull)
+    utils.info('This command is temporarily disabled')
+    utils.info('To set up Wifi, connect to the Spark over USB')
+    utils.info('On the Spark service page (actions, top right), you can configure Wifi settings')
+    # utils.confirm_mode()
+    # utils.confirm_usb()
+    # prepare_flasher(release, pull)
 
-    utils.info('Configuring wifi...')
-    run_flasher(release, 'wifi')
+    # utils.info('Configuring wifi...')
+    # run_flasher(release, 'wifi')
 
 
 @cli.command()
@@ -306,3 +283,24 @@ def particle(release, pull, command):
     utils.info('Starting Particle image...')
     utils.info("Type 'exit' and press enter to exit the shell")
     run_flasher(release, command)
+
+
+@cli.command()
+def disable_ipv6():
+    """Disable IPv6 support on the host machine.
+
+    Reason: https://github.com/docker/for-linux/issues/914
+    Should only be used if your services are having stability issues
+    """
+    utils.confirm_mode()
+    is_disabled = sh('cat /proc/sys/net/ipv6/conf/all/disable_ipv6', capture=True).strip()
+    if is_disabled == '1':
+        utils.info('IPv6 is already disabled')
+    elif is_disabled == '0' or utils.ctx_opts().dry_run:
+        utils.info('Disabling IPv6...')
+        sh('echo "net.ipv6.conf.all.disable_ipv6 = 1" | sudo tee -a /etc/sysctl.conf')
+        sh('echo "net.ipv6.conf.default.disable_ipv6 = 1" | sudo tee -a /etc/sysctl.conf')
+        sh('echo "net.ipv6.conf.lo.disable_ipv6 = 1" | sudo tee -a /etc/sysctl.conf')
+        sh('sudo sysctl -p')
+    else:
+        utils.info('Invalid result when checking IPv6 status: ' + is_disabled)
